@@ -1,4 +1,4 @@
-from wud.football import team_name_revise, get_hdc_result, get_hdc_return
+from wud.football import team_name_revise, get_hdc_result, get_hdc_return, tor_rong_win
 
 
 def test_team_name_revise():
@@ -34,4 +34,18 @@ def test_get_hdc_return():
     assert get_hdc_return('away', 0, 'home', '500') == 0
     assert get_hdc_return('home', 1,'away', '500') == -500
     assert get_hdc_return('away', 0.5, 'home', '500') == -250
-    assert get_hdc_return('away', 0.5, 'minus', '200') == -200
\ No newline at end of file
+    assert get_hdc_return('away', 0.5, 'minus', '200') == -200
+    
+def test_tor_rong_win():
+    assert tor_rong_win('0.5', 'home', '1', '0') == ('tor', 1)
+    assert tor_rong_win('0.25', 'home', '0', '0') == ('rong', 0.5)
+    assert tor_rong_win('0.75', 'home', '1', '0') == ('tor', 0.5)
+    assert tor_rong_win('0.75', 'home', '2', '0') == ('tor', 1)
+    assert tor_rong_win('0', 'home', '0', '0') == ('n_a', 0)
+    assert tor_rong_win('0', 'home', '1', '1') == ('n_a', 0)
+    assert tor_rong_win('1', 'home', '1', '0') == ('draw', 0)
+    assert tor_rong_win('1', 'away', '0', '1') == ('draw', 0)
+    assert tor_rong_win('1', 'home', '0', '0') == ('rong', 1)
+    assert tor_rong_win('0.5', 'home', '0', '0') == ('rong', 1)
+    assert tor_rong_win('0.25', 'home', '0', '1') == ('rong', 1)
+    assert tor_rong_win('0.75', 'home', '0', '0') == ('rong', 1)
