@@ -45,8 +45,8 @@ def get_s3_object(client_resource, region='us-east-1'):
         s3 = boto3.client(
         "s3",
         region_name = region,
-        aws_access_key_id = os.environ.get('AWS_ACCESS_KEY_ID'),
-        aws_secret_access_key = os.environ.get('AWS_SECRET_ACCESS_KEY'),
+        aws_access_key_id = ACCESS_KEY_ID,
+        aws_secret_access_key = ACCESS_SECRET_KEY,
         config=Config(signature_version='s3v4')
     )
     else:
